@@ -6,7 +6,7 @@ use Path::Class 'file', 'dir';
 use meon::Web::SPc;
 use meon::Web::Util;
 
-use Catalyst::Plugin::Authentication::Store::UserXML 0.02;
+use Catalyst::Plugin::Authentication::Store::UserXML 0.03;
 
 use Catalyst::Runtime 5.80;
 use Catalyst::Plugin::Session 0.37;
@@ -23,17 +23,19 @@ use Catalyst qw(
 extends 'Catalyst';
 use Catalyst::View::XSLT 0.10;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 __PACKAGE__->config(
     name => 'meon_web',
+    using_frontend_proxy => 1,
     'Plugin::ConfigLoader' => { file => dir(meon::Web::SPc->sysconfdir, 'meon', 'web-config.pl') },
     'Plugin::SmartURI' => { disposition => 'relative', },
     'root' => dir(meon::Web::SPc->datadir, 'meon', 'web', 'www'),
     'authentication' => {
         'userxml' => {
-            'folder'           => dir(meon::Web::SPc->sharedstatedir, 'meon-web', 'global-members'),
-            'user_folder_file' => 'index.xml',
+            'folder'             => dir(meon::Web::SPc->sharedstatedir, 'meon-web', 'global-members'),
+            'user_folder_file'   => 'index.xml',
+            'find_user_fallback' => 'find_user_fallback',
         }
     },
     'Plugin::Authentication' => {
@@ -60,6 +62,7 @@ __PACKAGE__->config(
         callback_param  => 'cb',
         expose_stash    => 'json',
     },
+    'Plugin::Session' => { expires => 4*60*60 },
 );
 
 __PACKAGE__->setup();
@@ -92,6 +95,7 @@ sub member {
     return meon::Web::Member->new(
         members_folder => $members_folder,
         username       => $c->user->username,
+        xml            => $c->user->xml,
     );
 }
 
@@ -132,6 +136,33 @@ sub format_dt {
     return $dt->strftime('%d.%m.%Y %H:%M:%S');
 }
 
+sub find_user_fallback {
+    my ($c, $authinfo) = @_;
+
+    my $username = $authinfo->{username};
+    my $storage = meon::Web::env->hostname_config->{'auth'}{'storage'} // '';
+    if ($storage eq 'session') {
+        my $user_xml = $c->session->{meon_Web_user_xml};
+        unless ($user_xml) {
+            $user_xml =
+                '<page xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns="http://web.meon.eu/" xmlns:w="http://web.meon.eu/">'
+                .'<meta><user xmlns="http://search.cpan.org/perldoc?Catalyst%3A%3APlugin%3A%3AAuthentication%3A%3AStore%3A%3AUserXML">'
+                .'<username>'.$username.'</username>'
+                .'</user></meta>'
+                .'<w:member-profile/>'
+                .'</page>';
+
+            $c->session->{meon_Web_user_xml} = $user_xml;
+        }
+        my $user = Catalyst::Plugin::Authentication::Store::UserXML::User->new({
+            xml_filename => file('/'),
+            xml          => XML::LibXML->load_xml(string => $user_xml),
+        });
+        return $user;
+    }
+    return undef;
+}
+
 1;
 
 __END__
@@ -207,9 +238,16 @@ L<Template::Tools::ttree>
 
 Jozef Kutej, C<< <jkutej at cpan.org> >>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 CONTRIBUTORS
+ 
+The following people have contributed to the meon::Web by committing their
+code, sending patches, reporting bugs, asking questions, suggesting useful
+advice, nitpicking, chatting on IRC or commenting on my blog (in no particular
+order):
 
-Copyright 2012 jkutej@cpan.org
+    Andrea Pavlovic
+
+=head1 LICENSE AND COPYRIGHT
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
